from django.core.management.base import BaseCommand, CommandError
from django.conf import settings
import os
import sys

class Command(BaseCommand):
    help = 'get settings'

    def add_arguments(self, parser):
        parser.add_argument('expected_tier', type=str)


    def handle(self, *args, **options):
        tier = None
        expected_tier = args[0]
        try:
            tier = settings.TIER
        except:
            teir = 'none'
        if tier == expected_tier:
            self.stdout.write('%s' % tier)
            sys.exit(0)
        else:
            self.stdout.write("TIER SETTING INCORRECT")
            sys.exit(1)



from distutils.core import setup
from setuptools import find_packages
from check_tier import VERSION


setup(
name='check-tier',
description='Sends an html email that populates a template with and object, dictionary or both',
author='Level Up',
author_email='os@lvlup.us',
version=VERSION,
packages=find_packages(),
license='GPL v3',
long_description=open('README.txt').read(),
include_package_data=True,
)
